.. _contributors:

Contributors
============

Thank you to the following contributors and others for their invaluble help
and advice in developing OnionBalance. Contributions of any kind (code,
documentation, testing) are very welcome.

* `Donncha Ó Cearbhaill <https://github.com/DonnchaC/>`_

  - Original author and maintainer of OnionBalance!!!

* `Federico Ceratto <https://github.com/FedericoCeratto>`_

  - Tireless assistance with Debian packaging and OnionBalance improvements.
  - Replaced and reimplemented the job scheduler.
  - Implemented support for Unix signals and added a status socket to
    retrieve information about the running service.

* `Michael Scherer <https://github.com/mscherer>`_

  - Improving the Debian installation documentation.

* `s7r <https://github.com/gits7r>`_

  - Assisted in testing and load testing OnionBalance from an early stage.
  - Many useful suggestions for performance and usability improvements.

* `Ceysun Sucu <https://github.com/csucu>`_

  - Added code to reconnect to the Tor control port while OnionBalance is
    running.

* `Alec Muffett <https://github.com/alecmuffett>`_

  - Extensively tested OnionBalance, found many bugs and made many
    suggestions to improve the software.

* `duritong <https://github.com/duritong>`_

  - Packaged OnionBalance for Fedora, CentOS, and Redhat 7 (EPEL repository).
